==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fLshr.h <==
// class soot.coffi.Instruction_Lshr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class b67aecbe55560d3 soot_coffi_Instruction__5fLshr
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fLshr_H_
#define _JC_soot_coffi_Instruction__5fLshr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fLshr$sub_refs	_jc_soot_coffi_Instruction__5fLshr$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fLshr$sub_nonrefs	_jc_soot_coffi_Instruction__5fLshr$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLshr$refs	_jc_soot_coffi_Instruction__5fLshr$refs;
typedef struct _jc_soot_coffi_Instruction__5fLshr$nonrefs	_jc_soot_coffi_Instruction__5fLshr$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLshr$object	_jc_soot_coffi_Instruction__5fLshr$object;

typedef const struct _jc_soot_coffi_Instruction__5fLshr$vmethods	_jc_soot_coffi_Instruction__5fLshr$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fLshr$vtable	_jc_soot_coffi_Instruction__5fLshr$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fLshr$vtype	_jc_soot_coffi_Instruction__5fLshr$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fLshr$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fLshr$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fLshr$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fLshr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fLshr$vmethods	soot_coffi_Instruction__5fLshr;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fLshr$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fLshr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLshr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLshr$refs {
    _jc_soot_coffi_Instruction__5fLshr$sub_refs	soot_coffi_Instruction__5fLshr;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLshr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLshr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fLshr$sub_nonrefs	soot_coffi_Instruction__5fLshr;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fLshr$object {
	_jc_soot_coffi_Instruction__5fLshr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fLshr$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fLshr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fLshr$vtype _jc_soot_coffi_Instruction__5fLshr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fLshr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fLshr$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fLshr_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fLshr.h <==
// class soot.coffi.Instruction_Lshr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class b67aecbe55560d3 soot_coffi_Instruction__5fLshr
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fLshr_H_
#define _JC_soot_coffi_Instruction__5fLshr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fLshr$sub_refs	_jc_soot_coffi_Instruction__5fLshr$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fLshr$sub_nonrefs	_jc_soot_coffi_Instruction__5fLshr$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLshr$refs	_jc_soot_coffi_Instruction__5fLshr$refs;
typedef struct _jc_soot_coffi_Instruction__5fLshr$nonrefs	_jc_soot_coffi_Instruction__5fLshr$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLshr$object	_jc_soot_coffi_Instruction__5fLshr$object;

typedef const struct _jc_soot_coffi_Instruction__5fLshr$vmethods	_jc_soot_coffi_Instruction__5fLshr$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fLshr$vtable	_jc_soot_coffi_Instruction__5fLshr$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fLshr$vtype	_jc_soot_coffi_Instruction__5fLshr$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fLshr$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fLshr$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fLshr$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fLshr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fLshr$vmethods	soot_coffi_Instruction__5fLshr;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fLshr$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fLshr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLshr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLshr$refs {
    _jc_soot_coffi_Instruction__5fLshr$sub_refs	soot_coffi_Instruction__5fLshr;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLshr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLshr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fLshr$sub_nonrefs	soot_coffi_Instruction__5fLshr;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fLshr$object {
	_jc_soot_coffi_Instruction__5fLshr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fLshr$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fLshr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fLshr$vtype _jc_soot_coffi_Instruction__5fLshr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fLshr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fLshr$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fLshr_H_ */
